@@ -167,6 +167,42 @@ void MessagingMenu::addNotification(NotificationData notificationData)
     }
 }
 
+void MessagingMenu::addCellBroadcastNotification(NotificationData notificationData)
+{
+    AccountEntry *account = TelepathyHelper::instance()->accountForId(notificationData.accountId);
+    if (!account) {
+        return;
+    }
+
+    mMessages[notificationData.encodedEventId] = notificationData;
+
+    GFile *file = NULL;
+    GIcon *icon = NULL;
+    file = g_file_new_for_uri(notificationData.icon.toUtf8().data());
+    icon = g_file_icon_new(file);
+
+    MessagingMenuMessage *message = messaging_menu_message_new(notificationData.encodedEventId.toUtf8().data(),
+                                                               icon,
+                                                               notificationData.notificationTitle.toUtf8().data(),
+                                                               "",
+                                                               notificationData.messageText.toUtf8().data(),
+                                                               notificationData.timestamp.toMSecsSinceEpoch() * 1000); // the value is expected to be in microseconds
+
+    g_signal_connect(message, "activate", G_CALLBACK(&MessagingMenu::messageActivateCallback), this);
+
+    messaging_menu_app_append_message(mMessagesApp, message, SOURCE_ID, true);
+
+    if (file) {
+        g_object_unref(file);
+    }
+    if (icon) {
+        g_object_unref(icon);
+    }
+    if (message) {
+        g_object_unref(message);
+    }
+}
+
 void MessagingMenu::addMessage(NotificationData notificationData)
 {
     // try to get a contact for that phone number
@@ -226,11 +262,11 @@ void MessagingMenu::addMessage(NotificationData notificationData)
                     displayLabel = QString::fromUtf8(C::gettext("Message to %1 from %2")).arg(notificationData.roomName).arg(displayLabel);
                 } else {
                     // TRANSLATORS : %1 is the recipient name
-                    displayLabel = QString::fromUtf8(C::gettext("Message to group from %1")).arg(displayLabel);
+                    displayLabel = QString::fromUtf8(C::gettext("Message to the group from %1")).arg(displayLabel);
                 }
             } else {
                 // TRANSLATORS : %1 is the recipient name
-                displayLabel = QString::fromUtf8(C::gettext("Message to group from %1")).arg(displayLabel);
+                displayLabel = QString::fromUtf8(C::gettext("Message to the group from %1")).arg(displayLabel);
             }
         }
 
@@ -311,11 +347,11 @@ void MessagingMenu::addCallToMessagingMenu(Call call, const QString &text, bool
                                           NULL // predefined values
                                           );
         const char *predefinedMessages[] = {
-                C::gettext("I missed your call - can you call me now?"),
-                C::gettext("I'm running late. I'm on my way."),
-                C::gettext("I'm busy at the moment. I'll call you later."),
-                C::gettext("I'll be 20 minutes late."),
-                C::gettext("Sorry, I'm still busy. I'll call you later."),
+                C::gettext("Missed your call \342\200\224 can you call me now?"),
+                C::gettext("Running late. On my way."),
+                C::gettext("Busy at the moment. Will call you later."),
+                C::gettext("I am 20 minutes late."),
+                C::gettext("Still busy. Will call you later."),
                 0
                 };
         messages = g_variant_new_strv(predefinedMessages, -1);
